---
title: Drop Python 3.9 and earlier support
type: change
author: mavam
created: 2025-12-06T00:03:02.541358Z
---

The minimum Python version is now 3.10. Also includes various CI fixes and repository URL corrections.
